``eradiate.notebook``
=====================

.. automodule:: eradiate.notebook
   :members:
   :no-autosummary:

``eradiate.notebook.tutorials``
-------------------------------

.. automodule:: eradiate.notebook.tutorials
   :members:
   :no-autosummary:
